module.exports = function(grunt) {

    // Project configuration.
    grunt.initConfig({
        pkg: grunt.file.readJSON('package.json'),

        stylus: {
            compileTeatro3: {
                options: {
                    compress: true,
                    define: {
                        platform: 'teatro3'
                    }
                },
                files: {
                    'tv_app/stb_html_ui_v3/css/main.min.css': 'tv_app/uiMiniFramework/styl/*.styl',
                    'tv_app/stb_html_ui_v3/css/themes/0/teatro3.min.css': [
                        'tv_app/stb_html_ui_v3/styl/themes/0/*.styl',
                        'tv_app/uiMiniFramework/styl/components/*.styl',
                        'tv_app/uiMiniFramework/styl/modules/*.styl'
                    ]
                }
            },
            compileGenericTeatro3: {
                options: {
                    compress: true,
                    define: {
                        platform: 'teatro3_generic'
                    }
                },
                files: {
                    'tv_app/stb_html_ui_v3/css/main.min.css': 'tv_app/uiMiniFramework/styl/*.styl',
                    'tv_app/stb_html_ui_v3/css/themes/0/teatro3_generic.min.css': [
                        'tv_app/stb_html_ui_v3/styl/themes/0/*.styl',
                        'tv_app/uiMiniFramework/styl/components/*.styl',
                        'tv_app/uiMiniFramework/styl/modules/*.styl'
                    ]
                }
            }
        },

        removelogging: {
            ui: {
                src: "tv_app/stb_html_ui_v3/js/app.min.js",
                dest: "tv_app/stb_html_ui_v3/js/app.min.js",
                options: {}
            },
            pluginInterface: {
                src: "tv_app/stb_html_ui_v3/js/pluginInterface.min.js",
                dest: "tv_app/stb_html_ui_v3/js/pluginInterface.min.js",
                options: {
                    methods: ['PluginInterface.Tools.debug', 'console.info']
                }
            }
        },

        uglify: {
            ui: {
                options: {
                    sourceMap: false,
                    beautify: false,
                    quoteStyle: 0,
                    compress:{
                        drop_console : true
                    }
                },
                files: {
                    'tv_app/stb_html_ui_v3/js/app.min.js': [
                        // UI mini framework
                        'tv_app/uiMiniFramework/namespaces/namespaces.js',
                        'tv_app/uiMiniFramework/tools/tools.js',
                        'tv_app/uiMiniFramework/config.js',
                        'tv_app/uiMiniFramework/globals.js',
                        'tv_app/uiMiniFramework/templates/templates.js',                       
                        'tv_app/uiMiniFramework/keys/keys.js',
                        'tv_app/uiMiniFramework/keys/sysKeys.js',
                        'tv_app/uiMiniFramework/keys/frontPanelKeys.js',
                        'tv_app/uiMiniFramework/serviceListCache/serviceListCache.js',
                        'tv_app/uiMiniFramework/components/context.js',
                        'tv_app/uiMiniFramework/components/component.js',
                        'tv_app/uiMiniFramework/components/buttonComponent.js',
                        'tv_app/uiMiniFramework/components/passwordComponent.js',
                        'tv_app/uiMiniFramework/components/spinnerComponent.js',
                        'tv_app/uiMiniFramework/components/progressComponent.js',
                        'tv_app/uiMiniFramework/components/timeComponent.js',
                        'tv_app/uiMiniFramework/components/dateComponent.js',
                        'tv_app/uiMiniFramework/components/durationComponent.js',
                        'tv_app/uiMiniFramework/components/labelComponent.js',
                        'tv_app/uiMiniFramework/components/textComponent.js',
                        'tv_app/uiMiniFramework/components/multilineLabelComponent.js',
                        'tv_app/uiMiniFramework/components/scrollableTextComponent.js',
                        'tv_app/uiMiniFramework/components/numberComponent.js',
                        'tv_app/uiMiniFramework/components/integerComponent.js',
                        'tv_app/uiMiniFramework/components/listComponent.js',
                        'tv_app/uiMiniFramework/components/simpleListComponent.js',
                        'tv_app/uiMiniFramework/components/traversableListComponent.js',
                        'tv_app/uiMiniFramework/components/ipAddressComponent.js',
                        'tv_app/uiMiniFramework/components/notification.js',
                        'tv_app/uiMiniFramework/components/confirmation.js',
                        'tv_app/uiMiniFramework/components/permanentInformation.js',
                        'tv_app/uiMiniFramework/components/playerComponent.js',
                        'tv_app/uiMiniFramework/components/imagePlayerComponent.js',
                        'tv_app/uiMiniFramework/components/radioButtonComponent.js',

                        'tv_app/uiMiniFramework/modules/input/input.js',
                        'tv_app/uiMiniFramework/modules/frontPanel/frontPanel.js',
                        'tv_app/uiMiniFramework/modules/notifications/notifications.js',
                        'tv_app/uiMiniFramework/modules/confirmations/confirmations.js',
                        'tv_app/uiMiniFramework/modules/permanentInformations/permanentInformations.js',
                        'tv_app/uiMiniFramework/modules/pinEntry/pinEntry.js',
                        'tv_app/uiMiniFramework/modules/loader/loader.js',
                        'tv_app/uiMiniFramework/modules/volumeBar/volumeBar.js',
                        'tv_app/uiMiniFramework/modules/radioPlayingOverlay/radioPlayingOverlay.js',
                        'tv_app/uiMiniFramework/modules/infoBanner/infoBanner.js',
                        'tv_app/uiMiniFramework/modules/clock/clock.js',
                        'tv_app/uiMiniFramework/modules/zapperWrapper/zapperWrapper.js',
                        'tv_app/uiMiniFramework/modules/usbDevices/usbDevices.js',
                        'tv_app/uiMiniFramework/modules/dummyVideoController/dummyVideoController.js',
                        'tv_app/uiMiniFramework/modules/testSuite/testSuite.js',
                        'tv_app/uiMiniFramework/modules/legend/legend.js',
                        'tv_app/uiMiniFramework/translations/translationManager.js',
                        'tv_app/uiMiniFramework/translations/languages.js',
                        // app files
                        'tv_app/stb_html_ui_v3/scripts/namespaces/namespaces.js',
                        'tv_app/stb_html_ui_v3/scripts/translations/translations_Teatro3.js',
                        'tv_app/stb_html_ui_v3/scripts/mappings/channelList/channelLists.js',
                        'tv_app/stb_html_ui_v3/scripts/mappings/epg/epgChangeFilters.js',
                        'tv_app/stb_html_ui_v3/scripts/mappings/epg/epgDescriptionItems.js',
                        'tv_app/stb_html_ui_v3/scripts/mappings/pinEntry/pinEntryItems.js',                        
                        'tv_app/stb_html_ui_v3/scripts/mappings/customConfirmations/customConfirmations.js',
                        'tv_app/stb_html_ui_v3/scripts/mappings/customPermanentInformations/customPermanentInformations.js',
                        'tv_app/stb_html_ui_v3/scripts/mappings/radioPlayingOverlay/radioPlayingOverlayItems.js',
                        'tv_app/stb_html_ui_v3/scripts/mappings/legend/legendItems.js',
                        // ---------------------------------------------------------------------------------------------
                        'tv_app/stb_html_ui_v3/scripts/app/keyHandlers/keyHandlers.js',
                        'tv_app/stb_html_ui_v3/scripts/app/callbacks/callbacks.js',
                        'tv_app/stb_html_ui_v3/scripts/app/init/init.js',
                        'tv_app/stb_html_ui_v3/scripts/app/main.js'
                    ]
                }
            },
            pluginInterface: {
                options: {
                    sourceMap: false,
                    quoteStyle: 0,
                    compress:{
                        drop_console : true,
                        pure_funcs: ['PluginInterface.Tools.debug']
                    }
                },
                files: {
                    'tv_app/stb_html_ui_v3/js/pluginInterface.min.js': [
                        'tv_app/pluginInterface/mappings/namespaces.js',
                        'tv_app/pluginInterface/helpers/tools.js',
                        'tv_app/pluginInterface/mappings/globals.js',
                        'tv_app/pluginInterface/mappings/dummies.js',
                        'tv_app/pluginInterface/setup.js',
                        'tv_app/pluginInterface/network.js',
                        'tv_app/pluginInterface/avSettings.js',
                        'tv_app/pluginInterface/cak.js',
                        'tv_app/pluginInterface/channelInstallation.js',
                        'tv_app/pluginInterface/epg.js',
                        'tv_app/pluginInterface/frontPanel.js',
                        'tv_app/pluginInterface/hbbtv.js',
                        'tv_app/pluginInterface/mediaBrowsing.js',
                        'tv_app/pluginInterface/mediaPlayback.js',
                        'tv_app/pluginInterface/parentalControl.js',
                        'tv_app/pluginInterface/pvr.js',
                        'tv_app/pluginInterface/releaseNotes.js',
                        'tv_app/pluginInterface/reminder.js',
                        'tv_app/pluginInterface/serviceZapper.js',
                        'tv_app/pluginInterface/signalStatus.js',
                        'tv_app/pluginInterface/streamComponents.js',
                        'tv_app/pluginInterface/vod.js',
                        'tv_app/pluginInterface/diseqc.js'
                    ]
                }
            }
        },

        yuidoc: {
            compile: {
                name: 'Teatro 3.0 JavaScript API',
                description: 'Iwedia Project Documentation',
                version: '1.0',
                options: {
                    paths: 'tv_app/pluginInterface',
                    outdir: './doc',
                    themedir: './node_modules/yuidoc-marviq-theme',
                    helpers: ['./node_modules/yuidoc-marviq-theme/helpers/helpers.js'],
                    exclude: ''
                }
            }
        },

        watch: {
            stylus: {
                // This defines what file patterns this task will watch. Can be a string or an array of files
                files: [
                    'tv_app/stb_html_ui_v3/styl/**/*.styl'
                ],
                // This defines which tasks to run when a watched file event occurs.
                tasks: ['stylus'],
                options : {
                    livereload: true
                }
            },
            uglify: {
                files: [
                    'tv_app/stb_html_ui_v3/scripts/app/**/*.js',
                    'tv_app/stb_html_ui_v3/scripts/mappings/**/*.js',
                    'tv_app/stb_html_ui_v3/scripts/tools/**/*.js'
                ],
                tasks: ['uglify']
            }
        }
    });

    grunt.loadNpmTasks('grunt-contrib-stylus');
    grunt.loadNpmTasks('grunt-contrib-uglify');
    grunt.loadNpmTasks('grunt-contrib-watch');
    grunt.loadNpmTasks('grunt-contrib-yuidoc');
    grunt.loadNpmTasks("grunt-remove-logging");
};