"use strict";


/**
 * DiSEqC interface
 * @class Diseqc
 * @namespace PluginInterface
 * @static
 */
PluginInterface.Diseqc = new function() {
    /*
     ***********************************************************************************************************
     PRIVATE VARIABLES AND FUNCTIONS
     ***********************************************************************************************************
     */
    /**
     * LNB enabled
     * @property _lnbEnabled
     * @private
     * @type {Number}
     * @default 1 = "ENABLE"
     */
    var _lnbEnabled = 1,

    /**
     * Tone enabled
     * @property _toneEnabled
     * @private
     * @type {Number}
     * @default 1 = "ENABLE"
     */
    _toneEnabled = 1,

    /**
     * Voltage
     * @property _voltage
     * @private
     * @type {Number}
     * @default 0 = "E13V"
     */
    _voltage = 0,

    /**
     * Tone burst
     * @property _toneBurst
     * @private
     * @type {Number}
     * @default 2 - "NOMINAL"
     */
    _toneBurst = 2,

    /**
     * Tone mode
     * @property _toneMode
     * @private
     * @type {Number}
     * @default 1 = "ENVELOPE"
     */
    _toneMode = 1,

    /**
     * Framing
     * @property _framing
     * @private
     * @type {Number}
     * @default 0 = "DEFAULT"
     */
    _framing = 0,

    /**
     * Pre transmit delay
     * @property _preTransmitDelay
     * @private
     * @type {Number}
     * @default 0
     */
    _preTransmitDelay = 0,

    /**
     * 22 kHz
     * @property _22kHz
     * @private
     * @type {Number}
     * @default 2 = "OFF"
     */
    _22kHz = 2,

    /**
     * Diseqc type
     * @property _diseqcType
     * @private
     * @type {Number}
     * @default 0 = "DEACTIVATE"
     */
    _diseqcType = 0,

    /**
     * Positioner
     * @property _positioner
     * @private
     * @type {Number}
     * @default 0 = "NONE"
     */
    _positioner = 0,

    /**
     * LNB volts
     * @property _lnbVolts
     * @private
     * @type {Number}
     * @default 0 = "OFF"
     */
    _lnbVolts = 0,

    /**
     * Motor moving type
     * @property _motorMovingType
     * @private
     * @type {Number}
     * @default 0 = "USER"
     */
    _motorMovingType = 0,

    /**
     * Motor position
     * @property _motorPosition
     * @private
     * @type {Number}
     * @default 0
     */
    _motorPosition = 0,

    /**
     * Motor drive (East-Qest)
     * @property _motorDrive
     * @private
     * @type {Number}
     * @default 0 = "EAST"
     */
    _motorDrive = 0,

    /**
     * Motor limit
     * @property _motorLimit
     * @private
     * @type {Number}
     * @default 2 = "DISABLE"
     */
    _motorLimit = 2,

    /**
     * Unicable antenna setup
     * @property _unicableAntennaSetup
     * @private
     * @type {Number}
     * @default 0 = "DEACTIVATE"
     */
    _unicableAntennaSetup = 0,

    /**
     * Unicable position
     * @property _unicablePosition
     * @private
     * @type {Number}
     * @default 1 = "A"
     */
    _unicablePosition = 1,

    /**
     * Unicable pin code
     * @property _unicablePin
     * @private
     * @type {Number}
     * @default 0
     */
    _unicablePin = 0,

    /**
     * Unicable SatCR state
     * @property _unicableSatCRState
     * @private
     * @type {Array}
     * @default [1, 0, 0, 0, 0, 0, 0, 0]
     */
    _unicableSatCRState = [1, 0, 0, 0, 0, 0, 0, 0],

    /**
     * Unicable SatCR frequency
     * @property _unicableSatCRFrequency
     * @private
     * @type {Array}
     * @default [1080, 1176, 1237, 1413, 1555, 1668, 1842, 1960]
     */
    _unicableSatCRFrequency = [1080, 1176, 1237, 1413, 1555, 1668, 1842, 1960];

    /*
     ***********************************************************************************************************
     PRIVILEGED PROPERTIES AND METHODS
     ***********************************************************************************************************
     */
    /**
     * Enumerated LNB states
     * @property eLnbEnabled
     * @type {{DISABLE: number, ENABLE: number}}
     * @final
     */
    this.eLnbEnabled = {
        DISABLE: 0,
        ENABLE: 1
    };

    /**
     * Enumerated Tone states
     * @property eToneEnabled
     * @type {{DISABLE: number, ENABLE: number}}
     * @final
     */
    this.eToneEnabled = {
        DISABLE: 0,
        ENABLE: 1
    };

    /**
     * Enumerated Voltage states
     * @property eVoltage
     * @type {{E13V: number, E18V: number}}
     * @final
     */
    this.eVoltage = {
        E13V: 0,
        E18V: 1
    };

    /**
     * Enumerated Tone burst values
     * @property eToneBurst
     * @type {{NONE: number, UNMODULATED: number, NOMINAL: number}}
     * @final
     */
    this.eToneBurst = {
        NONE: 0, // deactivate
        UNMODULATED: 1, //A[1x2]
        NOMINAL: 2 //B[1x2]
    };

    /**
     * Enumerated Tone mode values
     * @property eToneMode
     * @type {{TONE: number, ENVELOPE: number}}
     * @final
     */
    this.eToneMode = {
        TONE: 0,
        ENVELOPE: 1
    };

    /**
     * Enumerated Framing values
     * @property eFraming
     * @type {{DEFAULT: number, EXPECT_REPLY: number, DONT_EXPECT_REPLY: number}}
     * @final
     */
    this.eFraming = {
        DEFAULT: 0,
        EXPECT_REPLY: 1,
        DONT_EXPECT_REPLY: 2
    };

    /**
     * Enumerated 22 kHz states
     * @property e22kHz
     * @type {{AUTO: number, ON: number, OFF: number}}
     * @final
     */
    this.e22kHz = {
        AUTO: 0,
        ON: 1,
        OFF: 2
    };

    /**
     * Enumerated Diseqc type values
     * @property eDiseqcType
     * @type {{DEACTIVATE: number, AUTO: number, DISEQC_1_0_A: number, DISEQC_1_0_B: number, DISEQC_1_0_C: number, DISEQC_1_0_D: number, DISEQC_1_1_1: number, DISEQC_1_1_2: number, DISEQC_1_1_3: number, DISEQC_1_1_4: number, DISEQC_1_1_5: number, DISEQC_1_1_6: number, DISEQC_1_1_7: number, DISEQC_1_1_8: number, DISEQC_1_1_9: number, DISEQC_1_1_10: number, DISEQC_1_1_11: number, DISEQC_1_1_12: number, DISEQC_1_1_13: number, DISEQC_1_1_14: number, DISEQC_1_1_15: number, DISEQC_1_1_16: number}}
     * @final
     */
    this.eDiseqcType = {
        DEACTIVATE: 0,
        AUTO: 1,
        DISEQC_1_0_A: 2,
        DISEQC_1_0_B: 3,
        DISEQC_1_0_C: 4,
        DISEQC_1_0_D: 5,
        DISEQC_1_1_1: 6,
        DISEQC_1_1_2: 7,
        DISEQC_1_1_3: 8,
        DISEQC_1_1_4: 9,
        DISEQC_1_1_5: 10,
        DISEQC_1_1_6: 11,
        DISEQC_1_1_7: 12,
        DISEQC_1_1_8: 13,
        DISEQC_1_1_9: 14,
        DISEQC_1_1_10: 15,
        DISEQC_1_1_11: 16,
        DISEQC_1_1_12: 17,
        DISEQC_1_1_13: 18,
        DISEQC_1_1_14: 19,
        DISEQC_1_1_15: 20,
        DISEQC_1_1_16: 21
    };

    /**
     * Enumerated Positioner values
     * @property ePositioner
     * @type {{NONE: number, DISEQC: number, USUALS: number}}
     * @final
     */
    this.ePositioner = {
        NONE: 0,
        DISEQC: 1
    };

    /**
     * Enumerated LNB volts states
     * @property eLnbVolts
     * @type {{OFF: number, ON: number}}
     * @final
     */
    this.eLnbVolts = {
        OFF: 0,
        ON: 1
    };

    /**
     * Enumerated Motor moving type values
     * @property eMotorMovingType
     * @type {{USER: number, INSTALLER: number, GOTO_X: number, ADVANCED: number}}
     * @final
     */
    this.eMotorMovingType = {
        USER: 0,
        INSTALLER: 1,
        GOTO_X: 2,
        ADVANCED: 3 // recalculate, reset
    };

    /**
     * Enumerated Motor drive values
     * @property eMotorDrive
     * @type {{EAST: number, WEST: number}}
     * @final
     */
    this.eMotorDrive = {
        EAST: 0,
        WEST: 1
    };

    /**
     * Enumerated Motor limit values
     * @property eMotorLimit
     * @type {{EAST: number, WEST: number, DISABLE: number}}
     * @final
     */
    this.eMotorLimit = {
        EAST: 0,
        WEST: 1,
        DISABLE: 2
    };

    /**
     * Enumerated Unicable antenna setup values
     * @property eUnicableAntennaSetup
     * @type {{DEACTIVATE: number, SINGLE_DWELLING: number, MULTI_DWELLING: number}}
     * @final
     */
    this.eUnicableAntennaSetup = {
        DEACTIVATE: 0,
        SINGLE_DWELLING: 1,
        MULTI_DWELLING: 2
    };

    /**
     * Enumerated Unicable position values
     * @property eUnicablePosition
     * @type {{POSITION_A: number, POSITION_B: number}}
     * @final
     */
    this.eUnicablePosition = {
        POSITION_A: 1,
        POSITION_B: 2
    };

    /**
     * Enumerated Unicable SatCR state values
     * @property eUnicableSatCRState
     * @type {{OFF: number, ON: number}}
     * @final
     */
    this.eUnicableSatCRState = {
        OFF: 0,
        ON: 1
    };

    /**
     * Enumerated Unicable SatCR values
     * @property eUnicableSatCR
     * @type {{SAT_CR_0: number, SAT_CR_1: number, SAT_CR_2: number, SAT_CR_3: number, SAT_CR_4: number, SAT_CR_5: number, SAT_CR_6: number, SAT_CR_7: number}}
     * @final
     */
    this.eUnicableSatCR = {
        SAT_CR_0: 0,
        SAT_CR_1: 1,
        SAT_CR_2: 2,
        SAT_CR_3: 3,
        SAT_CR_4: 4,
        SAT_CR_5: 5,
        SAT_CR_6: 6,
        SAT_CR_7: 7
    };

    /**
     * Enumerated SAT CR predefined frequencies
     * @property eUnicableSatCR
     * @type {{SAT_CR_0: string, SAT_CR_1: string, SAT_CR_2: string, SAT_CR_3: string, SAT_CR_4: string, SAT_CR_5: string, SAT_CR_6: string, SAT_CR_7: string}}
     * @final
     */
    this.eSatCRPredefinedFrequencies = {
        SAT_CR_0: '1080',
        SAT_CR_1: '1176',
        SAT_CR_2: '1237',
        SAT_CR_3: '1413',
        SAT_CR_4: '1555',
        SAT_CR_5: '1668',
        SAT_CR_6: '1842',
        SAT_CR_7: '1960'
    };

    /**
     * Enable/Disable LNB
     * @method fEnableLNB
     * @param enable {Number} 0 disables LNB. 1 enables LNB.
     * @static
     */
    this.fEnableLNB = function (enable) {
        if (PluginInterface.Mappings.Globals.gPCTest) {
            _lnbEnabled = enable;
            return;
        }
        PluginInterface.Setup.stb.diseqcEnableLNB("" + enable);
    };

    /**
     * Check if LNB is enabled
     * @method fIsLNBEnabled
     * @returns {Number} Returns 0 if LNB is disabled. Otherwise, LNB is enabled and 1 is returned.
     * @static
     */
    this.fIsLNBEnabled = function () {
        if (PluginInterface.Mappings.Globals.gPCTest) {
            return _lnbEnabled;
        }
        return PluginInterface.Setup.stb.diseqcIsLNBEnabled("");
    };

    /**
     * Enable/Disable tone
     * @method fEnableTone
     * @param enable {Number} 0 disables tone. 1 enables tone.
     * @static
     */
    this.fEnableTone = function (enable) {
        if (PluginInterface.Mappings.Globals.gPCTest) {
            _toneEnabled = enable;
            return;
        }
        PluginInterface.Setup.stb.diseqcEnableTone("" + enable);
    };

    /**
     * Check if tone is enabled
     * @method fIsToneEnabled
     * @returns {Number} Returns 0 if tone is disabled. Otherwise, tone is enabled and 1 is returned.
     * @static
     */
    this.fIsToneEnabled = function () {
        if (PluginInterface.Mappings.Globals.gPCTest) {
            return _toneEnabled;
        }
        return PluginInterface.Setup.stb.diseqcIsToneEnabled("");
    };

    /**
     * Set voltage
     * @method fSetVoltage
     * @param voltage {Number} Voltage to be set
     * @static
     */
    this.fSetVoltage = function (voltage) {
        if (PluginInterface.Mappings.Globals.gPCTest) {
            _voltage = voltage;
            return;
        }
        PluginInterface.Setup.stb.diseqcSetVoltage("" + voltage);
    };

    /**
     * Get Voltage
     * @method fGetVoltage
     * @returns {Number} Voltage
     * @static
     */
    this.fGetVoltage = function () {
        if (PluginInterface.Mappings.Globals.gPCTest) {
            return _voltage;
        }
        return PluginInterface.Setup.stb.diseqcGetVoltage("");
    };

    /**
     * Set tone burst
     * @method fSetToneBurst
     * @param toneBurst {Number} Tone burst to be set
     * @static
     */
    this.fSetToneBurst = function (toneBurst) {
        if (PluginInterface.Mappings.Globals.gPCTest) {
            _toneBurst = toneBurst;
            return;
        }
        PluginInterface.Setup.stb.diseqcSetToneBurst("" + toneBurst);
    };

    /**
     * Get tone burst
     * @method fGetToneBurst
     * @returns {Number} Tone burst
     * @static
     */
    this.fGetToneBurst = function () {
        if (PluginInterface.Mappings.Globals.gPCTest) {
            return _toneBurst;
        }
        return PluginInterface.Setup.stb.diseqcGetToneBurst("");
    };

    /**
     * Set tone mode
     * @method fSetToneMode
     * @param toneMode {Number} Tone mode to be set
     * @static
     */
    this.fSetToneMode = function (toneMode) {
        if (PluginInterface.Mappings.Globals.gPCTest) {
            _toneMode = toneMode;
            return;
        }
        PluginInterface.Setup.stb.diseqcSetToneMode("" + toneMode);
    };

    /**
     * Get tone mode
     * @method fGetToneMode
     * @returns {Number} Tone mode
     * @static
     */
    this.fGetToneMode = function () {
        if (PluginInterface.Mappings.Globals.gPCTest) {
            return _toneMode;
        }
        return PluginInterface.Setup.stb.diseqcGetToneMode("");
    };

    /**
     * Set framing
     * @method fSetFraming
     * @param framing {Number} Framing to be set
     * @static
     */
    this.fSetFraming = function (framing) {
        if (PluginInterface.Mappings.Globals.gPCTest) {
            _framing = framing;
            return;
        }
        PluginInterface.Setup.stb.diseqcSetFraming("" + framing);
    };

    /**
     * Get framing
     * @method fGetFraming
     * @returns {Number} Framing
     * @static
     */
    this.fGetFraming = function () {
        if (PluginInterface.Mappings.Globals.gPCTest) {
            return _framing;
        }
        return PluginInterface.Setup.stb.diseqcGetFraming("");
    };

    /**
     * Set pre transmit delay
     * @method fSetPreTransmitDelay
     * @param preTransmitDelay {Number} pre transmit delay to be set
     * @static
     */
    this.fSetPreTransmitDelay = function (preTransmitDelay) {
        if (PluginInterface.Mappings.Globals.gPCTest) {
            _preTransmitDelay = preTransmitDelay;
            return;
        }
        PluginInterface.Setup.stb.diseqcSetPreTransmitDelay("" + preTransmitDelay);
    };

    /**
     * Get pre transmit delay
     * @method fGetPreTransmitDelay
     * @returns {Number} Pre transmit delay
     * @static
     */
    this.fGetPreTransmitDelay = function () {
        if (PluginInterface.Mappings.Globals.gPCTest) {
            return _preTransmitDelay;
        }
        return PluginInterface.Setup.stb.diseqcGetPreTransmitDelay("");
    };

    /**
     * Set 22 kHz
     * @method fSet22KHz
     * @param kHz_22 {Number} 22 kHz to be set
     * @static
     */
    this.fSet22KHz = function (kHz_22) {
        if (PluginInterface.Mappings.Globals.gPCTest) {
            _22kHz = kHz_22;
            return;
        }
        PluginInterface.Setup.stb.diseqcSet22KHz("" + kHz_22);
    };

    /**
     * Get 22 kHz
     * @method fGet22KHz
     * @returns {Number} 22 kHz
     * @static
     */
    this.fGet22KHz = function () {
        if (PluginInterface.Mappings.Globals.gPCTest) {
            return _22kHz;
        }
        return PluginInterface.Setup.stb.diseqcGet22KHz("");
    };

    /**
     * Set diseqc type
     * @method fSetDiseqcType
     * @param diseqcType {Number} Diseqc type to be set
     * @static
     */
    this.fSetDiseqcType = function (diseqcType) {
        if (PluginInterface.Mappings.Globals.gPCTest) {
            _diseqcType = diseqcType;
            return;
        }
        PluginInterface.Setup.stb.diseqcSetDiseqcType("" + diseqcType);
    };

    /**
     * Get diseqc type
     * @method fGetDiseqcType
     * @returns {Number} Diseqc type
     * @static
     */
    this.fGetDiseqcType = function () {
        if (PluginInterface.Mappings.Globals.gPCTest) {
            return _diseqcType;
        }
        return PluginInterface.Setup.stb.diseqcGetDiseqcType("");
    };

    /**
     * Set positioner
     * @method fSetPositioner
     * @param positioner {Number} Positioner to be set
     * @static
     */
    this.fSetPositioner = function (positioner) {
        if (PluginInterface.Mappings.Globals.gPCTest) {
            _positioner = positioner;
            return;
        }
        PluginInterface.Setup.stb.diseqcSetPositioner("" + positioner);
    };

    /**
     * Get positioner
     * @method fGetPositioner
     * @returns {Number} Positioner
     * @static
     */
    this.fGetPositioner = function () {
        if (PluginInterface.Mappings.Globals.gPCTest) {
            return _positioner;
        }
        return PluginInterface.Setup.stb.diseqcGetPositioner("");
    };

    /**
     * Set LNB volts
     * @method fSetLNBVolts
     * @param lnbVolts {Number} LNB volts to be set
     * @static
     */
    this.fSetLNBVolts = function (lnbVolts) {
        if (PluginInterface.Mappings.Globals.gPCTest) {
            _lnbVolts = lnbVolts;
            return;
        }
        PluginInterface.Setup.stb.diseqcSetLNBVolts("" + lnbVolts);
    };

    /**
     * Get LNB volts
     * @method fGetLNBVolts
     * @returns {Number} LNB volts
     * @static
     */
    this.fGetLNBVolts = function () {
        if (PluginInterface.Mappings.Globals.gPCTest) {
            return _lnbVolts;
        }
        return PluginInterface.Setup.stb.diseqcGetLNBVolts("");
    };

    /**
     * Set motor moving type
     * @method fSetSatMotorMovingType
     * @param motorMovingType {Number} Motor moving type to be set
     * @static
     */
    this.fSetSatMotorMovingType = function (motorMovingType) {
        if (PluginInterface.Mappings.Globals.gPCTest) {
            _motorMovingType = motorMovingType;
            return;
        }
        PluginInterface.Setup.stb.diseqcSetSatMotorMovingType("" + motorMovingType);
    };

    /**
     * Get motor moving type
     * @method fGetSatMotorMovingType
     * @returns {Number} Motor moving type
     * @static
     */
    this.fGetSatMotorMovingType = function () {
        if (PluginInterface.Mappings.Globals.gPCTest) {
            return _motorMovingType;
        }
        return PluginInterface.Setup.stb.diseqcGetSatMotorMovingType("");
    };

    /**
     * Set motor position
     * @method fSetSatMotorPosition
     * @param motorPosition {Number} Motor position to be set
     * @static
     */
    this.fSetSatMotorPosition = function (motorPosition) {
        if (PluginInterface.Mappings.Globals.gPCTest) {
            _motorPosition = motorPosition;
            return;
        }
        PluginInterface.Setup.stb.diseqcSetSatMotorPosition("" + motorPosition);
    };

    /**
     * Get motor position
     * @method fGetSatMotorPosition
     * @returns {Number} Motor position
     * @static
     */
    this.fGetSatMotorPosition = function () {
        if (PluginInterface.Mappings.Globals.gPCTest) {
            return _motorPosition;
        }
        return PluginInterface.Setup.stb.diseqcGetSatMotorPosition("");
    };

    /**
     * Set motor drive
     * @method fSetSatMotorDrive
     * @param motorDrive {Number} Motor drive to be set
     * @static
     */
    this.fSetSatMotorDrive = function (motorDrive) {
        if (PluginInterface.Mappings.Globals.gPCTest) {
            _motorDrive = motorDrive;
            return;
        }
        PluginInterface.Setup.stb.diseqcSetSatMotorDrive("" + motorDrive);
    };

    /**
     * Get motor drive
     * @method fGetSatMotorDrive
     * @returns {Number} Motor drive
     * @static
     */
    this.fGetSatMotorDrive = function () {
        if (PluginInterface.Mappings.Globals.gPCTest) {
            return _motorDrive;
        }
        return PluginInterface.Setup.stb.diseqcGetSatMotorDrive("");
    };

    /**
     * Stop motor
     * @method fSatMotorStop
     * @static
     */
    this.fSatMotorStop = function () {
        if (PluginInterface.Mappings.Globals.gPCTest) {
            return;
        }
        PluginInterface.Setup.stb.diseqcSatMotorStop("");
    };

    /**
     * Set motor drive one step
     * @method fSetSatMotorDriveOneStep
     * @param motorDrive {Number} Motor drive to be set
     * @static
     */
    this.fSetSatMotorDriveOneStep = function (motorDrive) {
        if (PluginInterface.Mappings.Globals.gPCTest) {
            _motorDrive = motorDrive;
            return;
        }
        PluginInterface.Setup.stb.diseqcSetSatMotorDriveOneStep("" + motorDrive);
    };

    /**
     * Get motor drive one step
     * @method fGetSatMotorDriveOneStep
     * @returns {Number} Motor drive
     * @static
     */
    this.fGetSatMotorDriveOneStep = function () {
        if (PluginInterface.Mappings.Globals.gPCTest) {
            return _motorDrive;
        }
        return PluginInterface.Setup.stb.diseqcGetSatMotorDriveOneStep("");
    };

    /**
     * Set motor limit
     * @method fSetSatMotorLimit
     * @param motorLimit {Number} Motor limit to be set
     * @static
     */
    this.fSetSatMotorLimit = function (motorLimit) {
        if (PluginInterface.Mappings.Globals.gPCTest) {
            _motorLimit = motorLimit;
            return;
        }
        PluginInterface.Setup.stb.diseqcSetSatMotorLimit("" + motorLimit);
    };

    /**
     * Get motor limit
     * @method fGetSatMotorLimit
     * @returns {Number} Motor limit
     * @static
     */
    this.fGetSatMotorLimit = function () {
        if (PluginInterface.Mappings.Globals.gPCTest) {
            return _motorLimit;
        }
        return PluginInterface.Setup.stb.diseqcGetSatMotorLimit("");
    };

    /**
     * Recalculate motor position
     * @method fSatMotorRecalculate
     * @param flag {Number} If flag is set to 1 then kSATINSTALL_YES will be applied.
     * @static
     */
    this.fSatMotorRecalculate = function (flag) {
        if (PluginInterface.Mappings.Globals.gPCTest) {
            return;
        }
        PluginInterface.Setup.stb.diseqcSatMotorRecalculate("" + flag);
    };

    /**
     * Reset motor position
     * @method fSatMotorResetPosition
     * @static
     */
    this.fSatMotorResetPosition = function () {
        if (PluginInterface.Mappings.Globals.gPCTest) {
            return;
        }
        PluginInterface.Setup.stb.diseqcSatMotorResetPosition("");
    };

    /**
     * Drive to motor position
     * @method fSatMotorDrivePosition
     * @param motorPosition {Number} Motor position to be driven.
     * @static
     */
    this.fSatMotorDrivePosition = function (motorPosition) {
        if (PluginInterface.Mappings.Globals.gPCTest) {
            return;
        }
        PluginInterface.Setup.stb.diseqcSatMotorDrivePosition("" + motorPosition);
    };

    /**
     * Load current antenna settings
     * @method fAntennaLoadSettings
     * @static
     */
    this.fAntennaLoadSettings = function () {
        if (PluginInterface.Mappings.Globals.gPCTest) {
            return;
        }
        PluginInterface.Setup.stb.antennaLoadSettings("");
    };

    /**
     * Save current antenna settings
     * @method fAntennaSaveSettings
     * @static
     */
    this.fAntennaSaveSettings = function () {
        if (PluginInterface.Mappings.Globals.gPCTest) {
            return;
        }
        PluginInterface.Setup.stb.antennaSaveSettings("");
    };

    /**
     * Set unicable antenna setup
     * @method fSetUnicableAntenna
     * @param value {Number} Unicable antenna setup value.
     * @static
     */
    this.fSetUnicableAntenna = function (value) {
        if (PluginInterface.Mappings.Globals.gPCTest) {
            _unicableAntennaSetup = value;
            return;
        }
        PluginInterface.Setup.stb.setUnicableAntenna("" + value);
    };

    /**
     * Get unicable antena setup
     * @method fGetUnicableAntenna
     * @returns {Number} Unicable antenna setup value.
     * @static
     */
    this.fGetUnicableAntenna = function () {
        if (PluginInterface.Mappings.Globals.gPCTest) {
            return _unicableAntennaSetup;
        }
        return PluginInterface.Setup.stb.getUnicableAntenna("");
    };

    /**
     * Set unicable position
     * @method fSetUnicablePosition
     * @param value {Number} Unicable position value.
     * @static
     */
    this.fSetUnicablePosition = function (value) {
        if (PluginInterface.Mappings.Globals.gPCTest) {
            _unicablePosition = value;
            return;
        }
        PluginInterface.Setup.stb.setUnicablePosition("" + value);
    };

    /**
     * Get unicable position
     * @method fGetUnicablePosition
     * @returns {Number} Unicable position value.
     * @static
     */
    this.fGetUnicablePosition = function () {
        if (PluginInterface.Mappings.Globals.gPCTest) {
            return _unicablePosition;
        }
        return PluginInterface.Setup.stb.getUnicablePosition("");
    };

    /**
     * Set unicable SatCR
     * @method fSetUnicableSatCR
     * @param index {Number} Unicable SatCR value.
     * @param state {Number} Unicable SatCR state value.
     * @param frequency {Number} Unicable SatCR frequency.
     * @static
     */
    this.fSetUnicableSatCR = function (index, state, frequency) {
        PluginInterface.Tools.debug('index: ' + index + ' | state: ' + state + ' | frequency: ' + frequency);
        if (PluginInterface.Mappings.Globals.gPCTest) {
            _unicableSatCRState[index] = state;
            _unicableSatCRFrequency[index] = frequency;
            return;
        }
        PluginInterface.Setup.stb.setUnicableSatCR("" + index, "" + state, "" + frequency);
    };

    /**
     * Get unicable SatCR state
     * @method fGetUnicableSatCRState
     * @param index {Number} Unicable SatCR value.
     * @returns {Number} Unicable SatCR state value.
     * @static
     */
    this.fGetUnicableSatCRState = function (index) {
        if (PluginInterface.Mappings.Globals.gPCTest) {
            return _unicableSatCRState[index];
        }
        return PluginInterface.Setup.stb.getUnicableSatCRState("" + index);
    };

    /**
     * Get unicable SatCR frequency
     * @method fGetUnicableSatCRFrequency
     * @param index {Number} Unicable SatCR value.
     * @returns {Number} Unicable SatCR frequency.
     * @static
     */
    this.fGetUnicableSatCRFrequency = function (index) {
        if (PluginInterface.Mappings.Globals.gPCTest) {
            return _unicableSatCRFrequency[index];
        }
        return PluginInterface.Setup.stb.getUnicableSatCRFrequency("" + index);
    };

    /**
     * Set unicable pin code
     * @method fSetUnicablePIN
     * @param value {Number} Unicable pin code.
     * @static
     */
    this.fSetUnicablePIN = function (value) {
        if (PluginInterface.Mappings.Globals.gPCTest) {
            _unicablePin = value;
            return;
        }
        PluginInterface.Setup.stb.setUnicablePIN("" + value);
    };

    /**
     * Get unicable pin code
     * @method fGetUnicablePIN
     * @returns {Number} Unicable pin code.
     * @static
     */
    this.fGetUnicablePIN = function () {
        if (PluginInterface.Mappings.Globals.gPCTest) {
            return _unicablePin;
        }
        return PluginInterface.Setup.stb.getUnicablePIN("");
    };

    /**
     * Check unicable SatCR and get information of signal quality and signal strenght through callback
     * @method fCheckUnicableSatCRSignalStart
     * @returns {String} Signal quality|strenght|bitErrorRate
     * @static
     */
    this.fCheckUnicableSatCRSignalStart = function (antennaSetup, position, satCRIndex, satCRFrequency, satCRPin, frequency, symbolRate, polarization) {
        if (PluginInterface.Mappings.Globals.gPCTest) {
            return "0|0|0";
        }
        var polarizationIndex = PluginInterface.ChannelInstallation.ePolarization.indexOf(polarization);
        return PluginInterface.Setup.stb.checkUnicableSatCRSignalStart("" + antennaSetup, "" + position, "" + satCRIndex, "" + satCRFrequency, "" + satCRPin, "" + frequency, "" + symbolRate, "" + polarizationIndex);
    };

    /**
     * Stop getting information of signal quality and signal strenght through callback for unicable SatCR
     * @method fCheckUnicableSatCRSignalStop
     * @static
     */
    this.fCheckUnicableSatCRSignalStop = function () {
        if (PluginInterface.Mappings.Globals.gPCTest) {
            return;
        }
        PluginInterface.Setup.stb.checkUnicableSatCRSignalStop("");
    };
};