"use strict";

/**
 * Info banner
 * @module Info Banner
 * @type Object
 */
UIMiniFramework.Modules.InfoBanner = {
    GUID: UIMiniFramework.Tools.getGUID(),
    // represents info banner node
    el: null,
    // css selector for info banner wrapper where it'll be appended
    wrapperSelector: UIMiniFramework.Config.uiAppWrapperSelector,
    // tells if info banner is created, but not shown
    isCreated: false,
    // tells if info banner is shown, must be created
    isShown: false,
    isAutoClose: false,
    autoCloseProtectionId: null,
    autoCloseProtectionTimeout: 12000,
    autoCloseTimeout: 0,
    autoCloseTimeoutId: null,
    eventType: null,
    arrow: {
        LEFT: '.leftArrow',
        RIGHT: '.rightArrow',
        UP: '.upArrow',
        DOWN: '.downArrow'
    },
    mode: 'short',
    modes: {
        SHORT: 'short',
        EXTENDED: 'extended',
        SERVICE: 'service'
    },
    isDataSet: {
        SHORT: false,
        EXTENDED: false,
        SERVICE: false
    },
    // refresh progress bar interval
    progressRefreshTimeoutId: null,
    eventDateTimeStart: null,
    eventDateTimeEnd: null,
    // standard indicators: key: value(correspond to css class for that indicator)
    indicators: {
        hd: {key: 'hd', status: false},
        uhd: {key: 'uhd', status: false},
        dolby: {key: 'dolby', status: false},
        paytv: {key: 'paytv', status: false},
        skip: {key: 'skip', status: false},
        lock: {key: 'lock', status: false},
        extInfoAvailability: {key: 'extInfoAvailability', status: false},
        aud: {key: 'aud', status: false},
        sub: {key: 'sub', status: false},
        hbbtv: {key: 'hbbtv', status: false},
        ttx: {key: 'ttx', status: false}
    },
    shiftedLcn: 0,
    shiftedData: {
        nextLcn: -1,
        previousLcn: 1
    },

    // progress bar statuses
    progressStatus: null,

    // scroll object - subcomponent that scrolls text
    scroll: {
        // total height of the scrollable content - unscrolled
        totalContentHeight: 0,
        // refers to .middleLeftBottom height in px
        visibleContentHeight: 0,
        // height of the scrollable progress in px, in proportion with the totalContentHeight and visibleContentHeight
        progressHeight: 0,
        // scroll progress height in px
        height: 0,
        // min scroll position in px
        min: 0,
        // max scroll position in px
        max: 0,
        // top position of the scrollable progress in px
        top: 0,
        // min content position in px
        contentMin: 0,
        // max content position in px; in relation with the
        contentMax: 0,
        //content top position in px
        contentTop: 0,
        // scroll / content ratio: 1 unit move of the scroll is equivalent of ratio unit move of the content
        ratio: 1,
        // scroll increment, default 1 px
        increment: 0.2,
        incrementShort: 0.2,
        // equivalent to line height in description
        incrementExtended: 29,
        progressSteps: 0,
        // auto scroll timeout in milliseconds
        autoScrollTimeout: 25,
        // auto scroll timeout id
        autoScrollTimeoutId: null
    },

    create: function (direction, index, list, isZapOnDigit, isCreated, isInfoKey) {
        // only allow for the following components to open info banner simultaneously
        if (!UIMiniFramework.Globals.isStandbyTriggered && (UIMiniFramework.Modules.Input.currentFocus == null || UIMiniFramework.Modules.PinEntry.isCreated || UIMiniFramework.Modules.Confirmations.isCreated || this.isCreated)) {
            // allow
        }
        else {
            return false;
        }
        this.autoCloseTimeout = UIMiniFramework.Globals.osdTimeout;
        if (UIMiniFramework.Config.MODULES.Hbbtv) {
            clearTimeout(UIMiniFramework.Modules.Hbbtv.hbbtvTimeoutId);
        }
        this.isCreated = true;
        UIMiniFramework.Globals.service.activeServiceList = (typeof list == 'undefined' || list < 0) ? parseInt(PluginInterface.ServiceZapper.fGetActiveServiceList(), 10) : list;
        UIMiniFramework.Globals.service.channelIndex = (typeof index == 'undefined' || index < 0) ? parseInt(PluginInterface.ServiceZapper.fGetActiveService(UIMiniFramework.Globals.service.activeServiceList), 10) : index;
        UIMiniFramework.Globals.service.totalServicesInCurrentServiceList = UIMiniFramework.ServiceListCache.serviceListCounts[UIMiniFramework.Globals.service.activeServiceList];
        isZapOnDigit = (typeof isZapOnDigit == 'undefined' || !isZapOnDigit) ? false : isZapOnDigit;
        isCreated = typeof isCreated == 'undefined' ? false : isCreated;
        isInfoKey = typeof isInfoKey == 'undefined' ? false : isInfoKey;
        UIMiniFramework.Globals.service.presentFollowingDataAvailable = false;

        if (isZapOnDigit && index < 0) {
            UIMiniFramework.Globals.service.channelIndex = -1;
        }

        console.log('CREATE QUICK ********************** ' + UIMiniFramework.Globals.service.channelIndex + ' | list = ' + UIMiniFramework.Globals.service.activeServiceList + ' | actualServiceList = ' + UIMiniFramework.Globals.service.actuallServiceList);
        if (!isCreated) {
            this.init();
            UIMiniFramework.Modules.Clock.create(true);
            this.mode = this.modes.SHORT;
            this.render();
            this.updateLabels();
            this.hide();
            this.addToDOM();
            this.isShown = false;
            this.autoCloseTimeout = UIMiniFramework.Globals.osdTimeout;
            this.isAutoClose = (this.autoCloseTimeout === 0 || isInfoKey) ? false : true;
            this.setArrows(this.arrow.LEFT, false);
            this.setArrows(this.arrow.RIGHT, false);
            this.focus();
        }
        var data = this.getCachedServiceData(direction, isZapOnDigit);
        // ******************************************* FOR QUICK I.B. DISPLAY ONLY THESE DATA, REST ON ZAP CALLBACK
        this.resetEventData();
        if (typeof data != 'undefined') {
            this.updateChannelTitle(data.name);
            this.updateChannelNumber(data.lcn);
            this.setActiveChannelIcon(!isZapOnDigit);
            if (!isZapOnDigit) {
                UIMiniFramework.Modules.FrontPanel.display(data.name);
            }
        }
        // *******************************************
        if (isInfoKey) {
            this.updateShortExtendedModeData();
            this.updateEventData(PluginInterface.ServiceZapper.eventType.PRESENT, isInfoKey);
            this.toggleEventType();
        }
        this.show();
        if (UIMiniFramework.Config.MODULES.Hbbtv) {
            UIMiniFramework.Modules.Hbbtv.hide();
        }
        UIMiniFramework.Modules.PermanentInformations.togglePermanentInfo();
    },

    init: function () {
        this.initProgressStatuses();
        this.initEventType();
    },

    initProgressStatuses: function () {
        this.progressStatus = {
            ZERO: {
                class: 'zero',
                label: '',
                limit: 0
            },
            POOR: {
                class: 'poor',
                label: UIMiniFramework.Translations.poor[UIMiniFramework.Globals.language],
                limit: 33
            },
            GOOD: {
                class: 'good',
                label: UIMiniFramework.Translations.good[UIMiniFramework.Globals.language],
                limit: 66
            },
            EXCELLENT: {
                class: 'excellent',
                label: UIMiniFramework.Translations.excellent[UIMiniFramework.Globals.language],
                limit: 100
            }
        }
    },

    getAudioTypeRealName: function (audioType) {
        switch (audioType) {
            case 'AC3':
                return 'AC3';
            case 'EAC3':
                return 'EAC3';
            case 'MPEG':
                return 'MPEG';
            default:
                return audioType;
        }
    },

    initEventType: function () {
        this.eventType = PluginInterface.ServiceZapper.eventType.PRESENT;
    },

    render: function () {
        // create info banner DOM element
        this.el = $(UIMiniFramework.Templates.infoBanner);
        this.el.addClass(this.mode);
    },

    updateLabels: function () {
        this.el.find('.eventTypeLabel').text(UIMiniFramework.Translations.type[UIMiniFramework.Globals.language] + ':');
        this.el.find('.ageLabel').text(UIMiniFramework.Translations.age[UIMiniFramework.Globals.language] + ':');
        this.el.find('.dateLabel').text(UIMiniFramework.Translations.date[UIMiniFramework.Globals.language] + ':');
        this.el.find('.recordText').text(UIMiniFramework.Translations.rec[UIMiniFramework.Globals.language]);
        this.el.find('.remindText').text(UIMiniFramework.Translations.remind[UIMiniFramework.Globals.language]);
        this.el.find('.row4 .title').text(UIMiniFramework.Translations.serviceInformation[UIMiniFramework.Globals.language]);
        this.el.find('.section5 .title').text(UIMiniFramework.Translations.carrierInformation[UIMiniFramework.Globals.language]);
        this.el.find('.satelliteName .label').text(UIMiniFramework.Translations.satelliteName[UIMiniFramework.Globals.language] + ':');
        this.el.find('.networkName .label').text(UIMiniFramework.Translations.networkName[UIMiniFramework.Globals.language] + ':');
        this.el.find('.frequency .label').text(UIMiniFramework.Translations.frequency[UIMiniFramework.Globals.language] + ':');
        this.el.find('.symbolRate .label').text(UIMiniFramework.Translations.symbolRateFec[UIMiniFramework.Globals.language] + ':');
        this.el.find('.polarization .label').text(UIMiniFramework.Translations.polarization[UIMiniFramework.Globals.language] + ':');
        this.el.find('.signal .label').text(UIMiniFramework.Translations.signal[UIMiniFramework.Globals.language] + ':');
        this.el.find('.quality .label').text(UIMiniFramework.Translations.quality[UIMiniFramework.Globals.language] + ':');
        this.el.find('.videoPid .label').text(UIMiniFramework.Translations.videoPid[UIMiniFramework.Globals.language] + ':');
        this.el.find('.audioPid .label').text(UIMiniFramework.Translations.audioPid[UIMiniFramework.Globals.language] + ':');
        this.el.find('.pcrPid .label').text(UIMiniFramework.Translations.pcrPid[UIMiniFramework.Globals.language] + ':');
        this.el.find('.videoType .label').text(UIMiniFramework.Translations.videoType[UIMiniFramework.Globals.language] + ':');
        this.el.find('.audioType .label').text(UIMiniFramework.Translations.audioType[UIMiniFramework.Globals.language] + ':');
        this.el.find('.dvbIndicator.age .label').text(UIMiniFramework.Translations.age[UIMiniFramework.Globals.language] + ':');
    },

    /**
     * update info banner data
     */
    updateData: function () {
        if (UIMiniFramework.Globals.service.channelIndex < UIMiniFramework.Globals.service.totalServicesInCurrentServiceList && UIMiniFramework.Globals.service.channelIndex >= 0) {
            this.updateChannelNumber();
            switch (this.mode) {
                case this.modes.SHORT:
                case this.modes.EXTENDED:
                    if (this.isDataSet.SHORT && this.isDataSet.EXTENDED) {
                        return false;
                    }
                    this.updateShortExtendedModeData();
                    this.isDataSet.SHORT = true;
                    this.isDataSet.EXTENDED = true;
                    break;
                case this.modes.SERVICE:
                    if (this.isDataSet.SERVICE) {
                        return false;
                    }
                    this.updateServiceModeData();
                    this.isDataSet.SERVICE = true;
                    break;
            }
        }
        else {
            this.resetAllData();
        }
    },

    updateShortExtendedModeData: function () {
        this.updateServiceData(true);
        this.updateServiceIndicators();
        this.initializeEventDescriptionScroll();
    },

    updateServiceModeData: function () {
        if (!this.isCreated) {
            return false;
        }
        var serviceList = UIMiniFramework.Globals.service.actuallServiceList || UIMiniFramework.Globals.service.activeServiceList;
        var activeTrackIndex = PluginInterface.StreamComponents.getActiveComponentIndex(PluginInterface.StreamComponents.type.AUDIO_TYPE);
        var audioInfo = PluginInterface.StreamComponents.fGetStreamTrackData(PluginInterface.StreamComponents.type.AUDIO_TYPE, activeTrackIndex);
        var videoInfo = PluginInterface.StreamComponents.fGetStreamTrackData(PluginInterface.StreamComponents.type.VIDEO_TYPE, 0);
        // service mode data
        this.setSatelliteName(PluginInterface.ServiceZapper.fGetServiceSatelliteName(serviceList, UIMiniFramework.Globals.service.channelIndex));
        this.setSymbolRate(PluginInterface.ChannelInstallation.fGetSymbolRate(), PluginInterface.ChannelInstallation.fGetFEC());
        this.setPolarization(PluginInterface.ChannelInstallation.fGetPolarization());
        this.setVideoPid(videoInfo.pid);
        this.setVideoType(PluginInterface.StreamComponents.VideoCodecNames[videoInfo.videoType]);
        this.setAudioPid(audioInfo.pid);
        this.setAudioType(this.getAudioTypeRealName(PluginInterface.StreamComponents.AudioCodecNames[audioInfo.audioType]));
        this.setPcrPid(PluginInterface.StreamComponents.fGetPcrPid());
        try {
            var signalInfo = PluginInterface.ServiceZapper.fGetSignalInfo(UIMiniFramework.Globals.service.frequency * 1000, UIMiniFramework.Globals.service.symbolRate, UIMiniFramework.Globals.service.polarization).split("|");
            this.setProgressStatus('quality', parseInt(signalInfo[0], 10)); // quality
            this.setProgressStatus('signal', parseInt(signalInfo[1], 10)); // signal
        }
        catch (error) {
            //console.log('ERROR: ' + error);
        }
    },

    resetAllData: function (isZappOnDigit) {
        this.setSatelliteName('');
        this.setSymbolRate('', '');
        this.setPolarization('');
        this.setVideoPid('');
        this.setVideoType('');
        this.setAudioPid('');
        this.setAudioType('');
        this.setPcrPid('');
        this.setProgressStatus('signal', 0);
        this.setProgressStatus('quality', 0);
        this.resetServiceData(isZappOnDigit);
        this.resetServiceIndicators();
        this.setActiveChannelIcon(false);
        this.resetEventData();
    },

    resetServiceData: function (isZappOnDigit) {
        isZappOnDigit = typeof isZappOnDigit == 'undefined' ? false : isZappOnDigit;
        this.setIndicator(this.indicators.lock.key, false);
        this.setIndicator(this.indicators.paytv.key, false);
        this.setIndicator(this.indicators.skip.key, false);
        this.setIndicator(this.indicators.hd.key, false);
        this.setIndicator(this.indicators.uhd.key, false);
        this.setIndicator(this.indicators.extInfoAvailability.key, false);
        this.updateChannelTitle('');
        this.setFrequency('');
        this.setNetworkName('');
        if (!isZappOnDigit) {
            UIMiniFramework.Globals.service.lcn = 0;
            UIMiniFramework.Globals.service.serviceName = ' ';
            UIMiniFramework.Modules.FrontPanel.display(' ');
        }
    },

    resetServiceIndicators: function () {
        this.setIndicator(this.indicators.aud.key, false);
        this.setIndicator(this.indicators.sub.key, false);
        this.setIndicator(this.indicators.ttx.key, false);
        this.setIndicator(this.indicators.dolby.key, false);
        this.setIndicator(this.indicators.hbbtv.key, false);
    },

    resetEventData: function () {
        if (this.isCreated) {
            this.updateEventTitle("");
            this.updateEventDescription("");
            this.updateEventTime("");
            this.updateEventType("");
            this.updateEventAge("");
            this.updateEventDate("", null, null);
            this.updateEventProgress(0);
        }
    },

    /**
     * Create fast zapper info banner
     */
    resetCloseTimeout: function () {
        if (this.isCreated && this.isAutoClose) {
            clearTimeout(this.autoCloseTimeoutId);
            this.autoCloseTimeoutId = setTimeout(this.closeTimeoutOccurred.bind(UIMiniFramework.Modules.InfoBanner), this.autoCloseTimeout);
        }
    },

    autoCloseProtection: function () {
        if (this.isCreated && this.isAutoClose) {
            clearTimeout(this.autoCloseProtectionId);
            this.autoCloseProtectionId = setTimeout(this.closeTimeoutOccurred.bind(UIMiniFramework.Modules.InfoBanner), this.autoCloseProtectionTimeout);
        }
    },

    postponeCloseTimeout: function () {
        if (UIMiniFramework.Globals.service.isZapped) {
            this.resetCloseTimeout();
        }
        else {
            clearTimeout(this.autoCloseTimeoutId);
        }
    },

    closeTimeoutOccurred: function () {
        this.destroy();
        if (UIMiniFramework.Config.MODULES.Pvr) {
            UIMiniFramework.Modules.Pvr.banner.destroy();
        }
        if (UIMiniFramework.Modules.Input.currentFocus == null) {
            UIMiniFramework.Modules.PinEntry.toggle.bind(UIMiniFramework.Modules.PinEntry);
        }
    },

    calculateServiceIndex: function (direction) {
        if (direction > 0) {
            UIMiniFramework.Globals.service.channelIndex++;
        }
        else if (direction < 0) {
            UIMiniFramework.Globals.service.channelIndex--;
        }
    },

    getCachedServiceData: function (direction) {
        var serviceList = UIMiniFramework.Globals.service.actuallServiceList || UIMiniFramework.Globals.service.activeServiceList;
        var start = UIMiniFramework.Globals.service.channelIndex;

        //console.log('GET CACHED SERVICE DATA: IsDigitZap = ' + isZapOnDigit + ' | ACTUALL SERVICE LIST = ' + UIMiniFramework.Globals.service.actuallServiceList + ' | SERVICE LIST = ' + serviceList + ' | CHANNEL INDEX = ' + UIMiniFramework.Globals.service.channelIndex);
        if (start < 0) {
            return UIMiniFramework.ServiceListCache.getEmptyData();
        }

        // if we are on hidden service - BEGIN -*************************************
        if (UIMiniFramework.Globals.service.actuallServiceList && UIMiniFramework.Globals.service.actuallServiceList != UIMiniFramework.Globals.service.activeServiceList && direction !== 0) {
            return this.getNextPreviousCachedServiceData(direction);
        }
        // if we are on hidden service - END ****************************************
        if (direction > 0) {
            if (++UIMiniFramework.Globals.service.channelIndex >= UIMiniFramework.ServiceListCache.serviceListCounts[serviceList]) {
                UIMiniFramework.Globals.service.channelIndex = 0
            }
            // second condition is to avoid infinite loop
            while (UIMiniFramework.ServiceListCache.serviceList[serviceList][UIMiniFramework.Globals.service.channelIndex].isSkipped && start != UIMiniFramework.Globals.service.channelIndex) {
                if (++UIMiniFramework.Globals.service.channelIndex >= UIMiniFramework.ServiceListCache.serviceListCounts[serviceList]) {
                    UIMiniFramework.Globals.service.channelIndex = 0
                }
            }
        }
        else if (direction < 0) {
            if (--UIMiniFramework.Globals.service.channelIndex < 0) {
                UIMiniFramework.Globals.service.channelIndex = UIMiniFramework.ServiceListCache.serviceListCounts[serviceList] - 1;
            }
            while (UIMiniFramework.ServiceListCache.serviceList[serviceList][UIMiniFramework.Globals.service.channelIndex].isSkipped && start != UIMiniFramework.Globals.service.channelIndex) {
                if (--UIMiniFramework.Globals.service.channelIndex < 0) {
                    UIMiniFramework.Globals.service.channelIndex = UIMiniFramework.ServiceListCache.serviceListCounts[serviceList] - 1;
                }
            }
        }
        //console.log(UIMiniFramework.Globals.service.channelIndex);
        //UIMiniFramework.Tools.printObject(UIMiniFramework.ServiceListCache.serviceList[serviceList][UIMiniFramework.Globals.service.channelIndex]);
        return UIMiniFramework.ServiceListCache.serviceList[serviceList][UIMiniFramework.Globals.service.channelIndex];
    },

    getNextPreviousCachedServiceData: function (direction) {
        var i = 0;
        var index = 0;
        var lcn = UIMiniFramework.ServiceListCache.serviceListLcn[UIMiniFramework.Globals.service.actuallServiceList][UIMiniFramework.Globals.service.channelIndex];
        //console.log('LCN = ' + lcn);
        if (direction > 0) {
            for (i = 0; i < UIMiniFramework.ServiceListCache.serviceListCounts[UIMiniFramework.Globals.service.activeServiceList] - 1; i++) {
                if (UIMiniFramework.ServiceListCache.serviceListLcn[UIMiniFramework.Globals.service.activeServiceList][i] > lcn && !UIMiniFramework.ServiceListCache.serviceList[UIMiniFramework.Globals.service.activeServiceList][i].isSkipped) {
                    //console.log('ACTIVE SERVICE LIST LCN = ' + UIMiniFramework.ServiceListCache.serviceListLcn[UIMiniFramework.Globals.service.activeServiceList][i]);
                    index = i;
                    break;
                }
            }
            //console.log('INDEX = ' + index);
        }
        else {
            for (i = UIMiniFramework.ServiceListCache.serviceListCounts[UIMiniFramework.Globals.service.activeServiceList] - 1; i > 0; i--) {
                if (UIMiniFramework.ServiceListCache.serviceListLcn[UIMiniFramework.Globals.service.activeServiceList][i] < lcn && !UIMiniFramework.ServiceListCache.serviceList[UIMiniFramework.Globals.service.activeServiceList][i].isSkipped) {
                    index = i;
                    break;
                }
            }
        }

        UIMiniFramework.Globals.service.actuallServiceList = null;
        UIMiniFramework.Globals.service.channelIndex = index;
        //UIMiniFramework.Tools.printObject(UIMiniFramework.ServiceListCache.serviceList[UIMiniFramework.Globals.service.activeServiceList][UIMiniFramework.Globals.service.channelIndex]);
        return UIMiniFramework.ServiceListCache.serviceList[UIMiniFramework.Globals.service.activeServiceList][UIMiniFramework.Globals.service.channelIndex];
    },

    /**
     * destroy info banner: remove it from DOM and nullify info banner element this.el
     * and reset all menu states like level etc.
     */
    destroy: function () {
        if (!this.isCreated) {
            return;
        }
        this.blur();
        UIMiniFramework.Modules.Clock.destroy();
        this.removeFromDOM();
        clearInterval(this.autoCloseProtectionId);
        clearTimeout(this.autoCloseTimeoutId);
        clearInterval(this.progressRefreshTimeoutId);
        this.autoCloseTimeoutId = null;
        this.progressRefreshTimeoutId = null;
        this.isAutoClose = false;
        this.isCreated = false;
        this.isShown = false;
        this.shiftedData.previousLcn = -1;
        this.shiftedData.nextLcn = -1;
        this.eventDateTimeStart = null;
        this.eventDateTimeEnd = null;
        this.eventType = null;
        this.resetIsDataSet();
        UIMiniFramework.Modules.PermanentInformations.togglePermanentInfo();
        if (UIMiniFramework.Config.MODULES.Pvr){
            UIMiniFramework.Modules.Pvr.banner.destroy();
        }
        if (UIMiniFramework.Config.MODULES.LanguageSubtitle) {
            UIMiniFramework.Modules.LanguageSubtitle.toggleSubtitle();
        }
    },

    /**
     * focus info banner so it can handle keypress events
     */
    focus: function () {
        UIMiniFramework.Modules.Input.setCurrentFocus(this);
    },

    // blur this screen
    blur: function () {
        if (UIMiniFramework.Modules.Input.currentFocus == this) {
            UIMiniFramework.Modules.Input.resetFocus();
        }
    },

    /**
     * add info banner to DOM
     */
    addToDOM: function () {
        $(this.wrapperSelector).append(this.el);
    },

    /**
     * remove info banner from DOM
     */
    removeFromDOM: function () {
        try {
            this.el.remove();
            this.el = null;
        }
        catch (error) {
            //console.log('Missing component link to DOM object');
        }
    },

    /**
     * show info banner - standard mode by default
     */
    show: function () {
        if (this.isCreated && !this.isShown) {
            UIMiniFramework.Modules.Clock.show();
            this.el.removeClass('invisible');
            this.isShown = true;
            if (UIMiniFramework.Config.MODULES.Pvr) {
                UIMiniFramework.Modules.Pvr.banner.checkPvrRecording();
            }
        }
    },

    resetIsDataSet: function () {
        this.isDataSet = {
            SHORT: false,
            EXTENDED: false,
            SERVICE: false
        }
    },

    /**
     * Toggle standard/extended info banner mode
     */
    toggleMode: function (direction) {
        if (this.isCreated) {
            this.isAutoClose = false;
            clearTimeout(this.autoCloseTimeoutId);
            if (direction == 1) {
                switch (this.mode) {
                    case this.modes.SHORT:
                        this.mode = this.modes.EXTENDED;
                        this.toggleEventType();
                        this.initializeEventDescriptionScroll();
                        break;
                    case this.modes.EXTENDED:
                        this.mode = this.modes.SHORT;
                        break;
                }
            }
            else if (direction == -1) {
                switch (this.mode) {
                    case this.modes.SHORT:
                        this.destroy();
                        return false;
                    case this.modes.EXTENDED:
                        this.mode = this.modes.SHORT;
                        break;
                }
            }
            this.el.removeClass(this.modes.SHORT + ' ' + this.modes.EXTENDED + ' ' + this.modes.SERVICE).addClass(this.mode);
            this.updateData();
        }
    },

    /**
     * hide info banner
     */
    hide: function () {
        this.el.addClass('invisible');
        this.isShown = false;
        UIMiniFramework.Modules.Clock.hide();
    },

    updateChannelNumber: function (channelIndex) {
        if (typeof channelIndex == "undefined") {
            var data = this.getCachedServiceData(0);
            channelIndex = data.lcn;
        }
        this.shiftedLcn = parseInt(channelIndex, 10);
        $('.infoBanner .channelNumber').text(channelIndex);
    },

    updateChannelTitle: function (data) {
        $('.infoBanner .row1 .channelTitle').text(data);
        $('.infoBanner .row2 .section6 .channelTitle').text(data);
    },

    updateChannelTitleOnDigit: function () {
        var data = this.getCachedServiceData(0, true);
        if (data) {
            $('.infoBanner .row1 .channelTitle').text(data.name);
            $('.infoBanner .row2 .section6 .channelTitle').text(data.name);
        }
        else {
            $('.infoBanner .row1 .channelTitle').text('');
            $('.infoBanner .row2 .section6 .channelTitle').text('');
        }
    },

    updateEventTitle: function (data) {
        $('.infoBanner .eventTitle').text(data);
    },

    updateEventDescription: function (data) {
        $('.infoBanner .eventDescription').html(data.replace(/\r\n|\r|\n/g, "<br>"));
    },

    updateEventTime: function (data) {
        $('.infoBanner .eventTime').text(data);
    },

    updateEventType: function (data) {
        $('.infoBanner .eventType').text(data);
    },

    updateEventAge: function (data) {
        $('.infoBanner .eventAge').text(data);
        $('.infoBannerFooter .dvbIndicator.age .value').text(data);
        if (data != '') {
            $('.infoBannerFooter .dvbIndicator.age').toggleClass('hidden', false);
        }
        else {
            $('.infoBannerFooter .dvbIndicator.age').toggleClass('hidden', true);
        }
    },

    updateEventDate: function (data, currentDateString, eventDateString) {
        data = data == '00.00.0000.' ? '' : data;
        var isEventDateVisible = (currentDateString == eventDateString || data == '');
        $('.infoBanner .eventDate').text(data).toggleClass('invisible', isEventDateVisible);
    },

    updateEventProgress: function (data) {
        $('.infoBanner .row3 .progress').css('width', data + '%');
    },

    setActiveChannelIcon: function (isActiveService) {
        $('.infoBanner .activeChannelIcon').toggleClass('hidden', !isActiveService);
    },

    setSatelliteName: function (value) {
        $('.infoBanner .satelliteName .value').text(value);
    },

    setNetworkName: function (value) {
        $('.infoBanner .networkName .value').text(value);
    },

    setFrequency: function (value) {
        UIMiniFramework.Globals.service.frequency = value;
        $('.infoBanner .frequency .value').text(value + "[MHz]");
    },

    setSymbolRate: function (value, fec) {
        UIMiniFramework.Globals.service.symbolRate = value;
        $('.infoBanner .symbolRate .value').text(value + "[kBps] / [" + fec + "]");
    },

    setPolarization: function (value) {
        UIMiniFramework.Globals.service.polarization = value.substring(0, 1);
        $('.infoBanner .polarization .value').text(value);
    },

    setVideoPid: function (value) {
        $('.infoBanner .videoPid .value').text(value);
    },

    setVideoType: function (value) {
        $('.infoBanner .videoType .value').text(value);
    },

    setAudioPid: function (value) {
        $('.infoBanner .audioPid .value').text(value);
    },

    setAudioType: function (value) {
        if (value == 'AC3' || value == 'EAC3') {
            $('.infoBanner .audioType .value').text('').toggleClass('officialDolby', true);
        }
        else {
            $('.infoBanner .audioType .value').text(value).toggleClass('officialDolby', false);
        }
    },

    setPcrPid: function (value) {
        $('.infoBanner .pcrPid .value').text(value);
    },

    /**
     * set specific indicator
     * @param indicator Object
     * @param isEnabled Boolean
     */
    setIndicator: function (indicator, isEnabled) {
        this.indicators[indicator].status = isEnabled;
        $('.infoBanner  .' + indicator).toggleClass('hidden', !isEnabled);
    },

    setArrows: function (arrowClass, isEnabled) {
        $('.infoBanner ' + arrowClass).toggleClass('invisible', !isEnabled);
    },

    /**
     * initialize scroll bar: set min/max positions, ratio and then reset to initial position
     */
    initializeEventDescriptionScroll: function () {
        this.scroll.increment = this.mode == this.modes.EXTENDED ? this.scroll.incrementExtended : this.scroll.incrementShort;
        this.scroll.visibleContentHeight = $('.infoBanner .eventDescriptionWrapper').height();
        this.scroll.totalContentHeight = $('.infoBanner .eventDescription').height();
        this.scroll.contentMax = -(this.scroll.totalContentHeight - this.scroll.visibleContentHeight);

        if (this.scroll.totalContentHeight > this.scroll.visibleContentHeight) {
            $('.infoBanner .scrollWrapper').removeClass('invisible');
        }
        else {
            $('.infoBanner .scrollWrapper').addClass('invisible');
            // no need to do further calculations as scroll is not displayed
            return;
        }

        this.scroll.height = $('.infoBanner .scrollProgressWrapper').height();
        this.scroll.progressSteps = Math.round((this.scroll.totalContentHeight - this.scroll.visibleContentHeight) / (this.scroll.increment));
        this.scroll.progressHeight = this.scroll.height / (this.scroll.progressSteps + 1);
        this.scroll.max = this.scroll.increment * this.scroll.progressSteps;
        this.resetScroll();
    },

    /**
     * reset scroll: set content top position and scroll top position to min positions
     */
    resetScroll: function () {
        this.scroll.increment = this.mode == this.modes.EXTENDED ? this.scroll.incrementExtended : this.scroll.incrementShort;
        this.scroll.top = this.scroll.min;
        this.scroll.contentTop = this.scroll.contentMin;
        $('.infoBanner .scrollProgress').css('top', this.scroll.min + 'px');
        $('.infoBanner .eventDescription').css('top', this.scroll.contentMin + 'px');
        $('.infoBanner .scrollProgress').css('height', this.scroll.progressHeight + 'px');
        clearInterval(this.autoScrollTimeoutId);
    },

    shiftHorizontal: function (direction) {
        if (direction == 1) {
            this.eventType = PluginInterface.ServiceZapper.eventType.FOLLOWING;
            this.updateEventData(PluginInterface.ServiceZapper.eventType.FOLLOWING, true);
            $('.infoBannerFooter .remindText').text(UIMiniFramework.Translations.remind[UIMiniFramework.Globals.language]);
        }
        else {
            this.eventType = PluginInterface.ServiceZapper.eventType.PRESENT;
            this.updateEventData(PluginInterface.ServiceZapper.eventType.PRESENT, true);
        }
        this.toggleEventType();
    },

    // up -1 | down 1
    shiftVertical: function (direction) {
        //console.log('SHIFTED LCN = ' + this.shiftedLcn + ' | DATA LCN = ' + UIMiniFramework.Globals.service.lcn + ' | ACTUAL SERVICE LIST = ' + UIMiniFramework.Globals.service.actuallServiceList);
        var actualServiceList = UIMiniFramework.Globals.service.actuallServiceList;
        if (actualServiceList && direction !== 0 && this.shiftedLcn == UIMiniFramework.Globals.service.lcn) {
            var index = 0;
            var lcn = UIMiniFramework.ServiceListCache.serviceListLcn[UIMiniFramework.Globals.service.actuallServiceList][UIMiniFramework.Globals.service.channelIndex];
            UIMiniFramework.Globals.service.actuallServiceList = null;
            //console.log('LCN = ' + lcn);

            var i = 0;
            if (direction < 0) {
                //console.log('COUNT = ' + UIMiniFramework.ServiceListCache.serviceListCounts[UIMiniFramework.Globals.service.activeServiceList]);
                for (i = 0; i < UIMiniFramework.ServiceListCache.serviceListCounts[UIMiniFramework.Globals.service.activeServiceList] - 1; i++) {
                    if (UIMiniFramework.ServiceListCache.serviceListLcn[UIMiniFramework.Globals.service.activeServiceList][i] > lcn) {
                        //console.log('ACTIVE SERVICE LIST LCN = ' + UIMiniFramework.ServiceListCache.serviceListLcn[UIMiniFramework.Globals.service.activeServiceList][i]);
                        index = i;
                        break;
                    }
                }
                this.shiftedData.nextLcn = UIMiniFramework.ServiceListCache.serviceListLcn[UIMiniFramework.Globals.service.activeServiceList][index];
            }
            else {
                for (i = UIMiniFramework.ServiceListCache.serviceListCounts[UIMiniFramework.Globals.service.activeServiceList] - 1; i > 0; i--) {
                    if (UIMiniFramework.ServiceListCache.serviceListLcn[UIMiniFramework.Globals.service.activeServiceList][i] < lcn || (UIMiniFramework.Globals.service.channelIndex === 0 && UIMiniFramework.Globals.service.activeServiceList == actualServiceList)) {
                        //console.log('ACTIVE SERVICE LIST LCN = ' + UIMiniFramework.ServiceListCache.serviceListLcn[UIMiniFramework.Globals.service.activeServiceList][i]);
                        index = i;
                        break;
                    }
                }
                this.shiftedData.previousLcn = UIMiniFramework.ServiceListCache.serviceListLcn[UIMiniFramework.Globals.service.activeServiceList][index];
            }
            //console.log('CHANNEL INDEX = ' + index);
            UIMiniFramework.Globals.service.channelIndex = index;
        }
        else {
            UIMiniFramework.Globals.service.actuallServiceList = null;
            this.incrementChannelIndex(direction);
            if (actualServiceList) {
                lcn = UIMiniFramework.ServiceListCache.serviceListLcn[UIMiniFramework.Globals.service.activeServiceList][UIMiniFramework.Globals.service.channelIndex];
                //console.log('EXCEPTION LCN = ' + lcn + ' | PREVIOUS = ' + this.shiftedData.previousLcn + ' | NEXT = ' + this.shiftedData.nextLcn);
                if (direction < 0) {
                    if (lcn > this.shiftedData.previousLcn && (lcn <= this.shiftedData.nextLcn || this.shiftedData.nextLcn == -1)) {
                        UIMiniFramework.Globals.service.actuallServiceList = actualServiceList;
                        if (UIMiniFramework.Globals.service.activeServiceList != UIMiniFramework.Globals.service.actuallServiceList) {
                            UIMiniFramework.Globals.service.channelIndex = UIMiniFramework.ServiceListCache.serviceListLcn[UIMiniFramework.Globals.service.actuallServiceList].indexOf(UIMiniFramework.Globals.service.lcn);
                        }
                    }
                }
                else {
                    if (lcn < this.shiftedData.nextLcn && (lcn >= this.shiftedData.previousLcn || this.shiftedData.previousLcn == -1)) {
                        UIMiniFramework.Globals.service.actuallServiceList = actualServiceList;
                        if (UIMiniFramework.Globals.service.activeServiceList != UIMiniFramework.Globals.service.actuallServiceList) {
                            UIMiniFramework.Globals.service.channelIndex = UIMiniFramework.ServiceListCache.serviceListLcn[UIMiniFramework.Globals.service.actuallServiceList].indexOf(UIMiniFramework.Globals.service.lcn);
                        }
                    }
                }
            }
        }

        //console.log('XXX ACTUAL LIST = ' + UIMiniFramework.Globals.service.actuallServiceList);
        //console.log('XXX CHANNEL INDEX = ' + UIMiniFramework.Globals.service.channelIndex);
        this.updateChannelNumber();
        this.updateServiceData(false);
        this.updateEventData(PluginInterface.ServiceZapper.eventType.PRESENT, true);
        UIMiniFramework.Globals.service.actuallServiceList = actualServiceList;
    },

    incrementChannelIndex: function (direction) {
        UIMiniFramework.Globals.service.channelIndex = UIMiniFramework.Globals.service.channelIndex + (-direction);
        if (UIMiniFramework.Globals.service.channelIndex >= UIMiniFramework.Globals.service.totalServicesInCurrentServiceList || UIMiniFramework.Globals.service.channelIndex < 0) {
            if (direction < 0) {
                UIMiniFramework.Globals.service.channelIndex = 0;
            }
            else {
                UIMiniFramework.Globals.service.channelIndex = UIMiniFramework.Globals.service.totalServicesInCurrentServiceList - 1;
            }
        }
    },

    scrollVertical: function (direction) {
        var top = this.scroll.top + direction * this.scroll.progressHeight;
        if (Math.abs(this.scroll.contentTop - (direction * this.scroll.increment)) > this.scroll.max || this.scroll.totalContentHeight <= this.scroll.visibleContentHeight) {
            return false;
        }
        if (top < this.scroll.min) {
            if (this.scroll.contentTop < 0) {
                top = 0;
            }
            else {
                return false;
            }
        }
        this.scroll.top = top;
        this.scroll.contentTop = this.scroll.contentTop - (direction * this.scroll.increment);

        $('.infoBanner .scrollProgress').css('top', top + 'px');
        $('.infoBanner .eventDescription').css('top', this.scroll.contentTop + 'px');
        return true;
    },

    toggleEventType: function () {
        $('.infoBanner .scheduleWrapper').toggleClass('hidden', this.eventType == PluginInterface.ServiceZapper.eventType.PRESENT);
    },

    updateEventData: function (eventType, isInfoKey) {
        console.log('update event data ' + eventType);
        if (!this.isCreated) {
            return false;
        }

        isInfoKey = typeof isInfoKey == 'undefined' ? false : isInfoKey;
        var event = null;
        var serviceList = UIMiniFramework.Globals.service.actuallServiceList || UIMiniFramework.Globals.service.activeServiceList;
        var channelIndex = UIMiniFramework.Globals.service.channelIndex;
        var isUhdEvent = PluginInterface.ServiceZapper.fCheckOccasionalUhdEvent();
        if (isUhdEvent) {
            channelIndex = PluginInterface.ServiceZapper.fGetUhdChannelIndex();
        }
        if (eventType == PluginInterface.ServiceZapper.eventType.PRESENT) {
            this.setArrows(this.arrow.LEFT, false);
            this.setArrows(this.arrow.RIGHT, true);
            event = PluginInterface.Epg.fGetEpgPresentData(serviceList, channelIndex);
        } else {
            this.setArrows(this.arrow.LEFT, true);
            this.setArrows(this.arrow.RIGHT, false);
            event = PluginInterface.Epg.fGetEpgFollowingData(serviceList, channelIndex);
        }
        //UIMiniFramework.Tools.printObject(event);
        if (event === null || typeof event == 'undefined' || !event || (event && event.startt == -1)) {
            this.resetEventData();
            UIMiniFramework.Globals.service.presentFollowingDataAvailable = false;
            return false;
        }

        // do not set this flag is info banner is opened with info key because have to wait p/f update callback on event change
        if (!isInfoKey) {
            UIMiniFramework.Globals.service.presentFollowingDataAvailable = true;
        }

        this.updateEventTitle(event.name);
        this.updateEventDescription(event.extendedDescription);
        if (event.endt - event.startt > 0) {
            this.updateEventTime(event.startdt.substr(11, 5) + "-" + event.enddt.substr(11, 5));
        }
        else {
            this.updateEventProgress(0);
            this.updateEventTime('');
        }
        this.updateEventType(event.genre);
        this.updateEventAge(event.parental == 0 ? '-' : event.parental);

        var timedate = PluginInterface.Setup.fGetTimeDate();
        this.eventDateTimeStart = UIMiniFramework.Tools.getDateTimeObjectFromDateTimeString(event.startdt);
        this.eventDateTimeEnd = UIMiniFramework.Tools.getDateTimeObjectFromDateTimeString(event.enddt);

        clearInterval(this.progressRefreshTimeoutId);
        this.progressRefreshTimeoutId = setInterval(this.refreshProgress.bind(UIMiniFramework.Modules.InfoBanner), 30000);
        this.refreshProgress(timedate);

        //yyyy:mm:dd -> dd.mm.yyyy.
        this.updateEventDate(event.startdt.substr(8, 2) + "." + event.startdt.substr(5, 2) + "." + event.startdt.substr(0, 4) + ".", timedate.substr(0, 10), event.startdt.substr(0, 10));
        $('.infoBanner .section1.eventTitle').toggleClass('scheduled', parseInt(event.isRecordSet, 10) === 1);
        $('.infoBanner .section1.eventTitle').toggleClass('remind', parseInt(event.isReminderSet, 10) === 1);

        if (this.mode == this.modes.EXTENDED) {
            this.initializeEventDescriptionScroll();
        }
    },

    getProgressStatus: function (value) {
        if (value == this.progressStatus.ZERO.limit) {
            return this.progressStatus.ZERO.label;
        }
        else if (value < this.progressStatus.POOR.limit) {
            return this.progressStatus.POOR.label;
        }
        else if (value < this.progressStatus.GOOD.limit) {
            return this.progressStatus.GOOD.label;
        }
        else if (value <= this.progressStatus.EXCELLENT.limit) {
            return this.progressStatus.EXCELLENT.label;
        }
    },

    setProgressStatus: function (progressClass, value) {
        $('.infoBanner .section5 .' + progressClass + ' .percent').text(value + '%');
        $('.infoBanner .section5 .' + progressClass + ' .state').text(this.getProgressStatus(value));
        $('.infoBanner .section5 .' + progressClass + ' .progress').css('width', value + '%');
        $('.infoBanner .section5 .' + progressClass + ' .progress').removeClass(this.progressStatus.POOR.class + ' ' + this.progressStatus.GOOD.class + ' ' + this.progressStatus.EXCELLENT.class);
        if (value < this.progressStatus.POOR.limit) {
            $('.infoBanner .section5 .' + progressClass + ' .progress').addClass(this.progressStatus.POOR.class);
        }
        else if (value < this.progressStatus.GOOD.limit) {
            $('.infoBanner .section5 .' + progressClass + ' .progress').addClass(this.progressStatus.GOOD.class);
        }
        else if (value <= this.progressStatus.EXCELLENT.limit) {
            $('.infoBanner .section5 .' + progressClass + ' .progress').addClass(this.progressStatus.EXCELLENT.class);
        }
    },

    /**
     * refresh event progress
     */
    refreshProgress: function (currentTime) {
        if (!currentTime) currentTime = PluginInterface.Setup.fGetTimeDate();

        var cdt = currentTime.split(":");
        cdt = new Date(cdt[0], cdt[1] - 1, cdt[2], cdt[3], cdt[4], cdt[5]);

        var progress = (cdt - this.eventDateTimeStart) / (this.eventDateTimeEnd - this.eventDateTimeStart) * 100;
        this.updateEventProgress(progress);
    },

    fastZapper: function(channelIndex, isZappOnDigit){
        this.postponeCloseTimeout();
        this.resetIsDataSet();
        // create info banner from the callback - async way - only if no active focuses - no active apps
        if (!this.isCreated && UIMiniFramework.Modules.Input.currentFocus == null) {
            // direction, channelIndex, serviceIndex, isZapOnDigit
            this.create(0, UIMiniFramework.Globals.service.channelIndex, -1, isZappOnDigit);
        }
        else {
            //clear components indicators
            this.setIndicator(this.indicators.lock.key, false);
            this.setIndicator(this.indicators.paytv.key, false);
            this.setIndicator(this.indicators.skip.key, false);
            this.setIndicator(this.indicators.hd.key, false);
            this.setIndicator(this.indicators.uhd.key, false);
            this.setIndicator(this.indicators.extInfoAvailability.key, false);
            this.resetServiceIndicators();
        }

        clearInterval(this.progressRefreshTimeoutId);
        clearTimeout(this.autoCloseTimeoutId);

        if (isZappOnDigit) {
            this.setActiveChannelIcon(false);
            this.updateChannelNumber(channelIndex);
            this.updateChannelTitleOnDigit();
        }

        //console.log('UIMiniFramework.Globals.service.channelIndex = ' + UIMiniFramework.Globals.service.channelIndex);
        if (UIMiniFramework.Globals.service.channelIndex < 0) {
            this.resetAllData(isZappOnDigit);
        }
        else {
            this.resetEventData();
        }
    },

    zapperCallback: function (components, isError) {
        this.updateRadioPlayingIcon(components);
        if (this.isCreated) {
            this.autoCloseProtection();
            this.resetCloseTimeout();
            this.setActiveChannelIcon(true);
            clearInterval(this.progressRefreshTimeoutId);
            if (UIMiniFramework.Globals.service.channelIndex < UIMiniFramework.Globals.service.totalServicesInCurrentServiceList && UIMiniFramework.Globals.service.channelIndex >= 0) {
                setTimeout(function () {
                    UIMiniFramework.Modules.InfoBanner.updateChannelNumber();
                    UIMiniFramework.Modules.InfoBanner.updateServiceData(true);
                    UIMiniFramework.Modules.InfoBanner.updateEventData(PluginInterface.ServiceZapper.eventType.PRESENT, false);
                }, 35);
                switch (this.mode) {
                    case this.modes.SERVICE:
                        setTimeout(function () {
                            UIMiniFramework.Modules.InfoBanner.updateServiceModeData();
                        }, 60);
                        break;
                }
            }
            else {
                this.resetAllData();
            }
        }
    },

    updateRadioPlayingIcon: function (components) {
        components = (components && components.length > 0) ? components : false;
        var serviceList = UIMiniFramework.Globals.service.actuallServiceList || UIMiniFramework.Globals.service.activeServiceList;
        var data = PluginInterface.ServiceZapper.fGetServiceData(serviceList, UIMiniFramework.Globals.service.activeChannelIndex);
        clearTimeout(UIMiniFramework.Modules.RadioPlayingOverlay.lockedOverlayTimeoutId);
        //if radio service and doesn't have hbbtv autostart
        //hbbtv app should be present for radio when we enter menus, disabled feature duo to change in browser z-order, hbbtv browser is on top of tv browser.
        if (data.type == 2 /*&& components && components[5] != "1"*/) {
            UIMiniFramework.Modules.RadioPlayingOverlay.create(data.name);
            UIMiniFramework.Modules.RadioPlayingOverlay.lockedOverlayTimeoutId = setTimeout(ui.App.Tools.toggleLockedOverlay.bind(ui.App.Tools, false), 800);
        }
        else {
            UIMiniFramework.Modules.RadioPlayingOverlay.destroy();
        }
    },

    updateFrontPanel: function () {
        var serviceList = UIMiniFramework.Globals.service.actuallServiceList || UIMiniFramework.Globals.service.activeServiceList;
        var data = UIMiniFramework.ServiceListCache.serviceList[serviceList][UIMiniFramework.Globals.service.activeChannelIndex];
        UIMiniFramework.Globals.service.serviceName = data.name;
        // do not update when epg is active
        if (UIMiniFramework.Config.MODULES.TvGuide && UIMiniFramework.Modules.TvGuide.isCreated || UIMiniFramework.Modules.Menu.isCreated) {
            return false;
        }
        UIMiniFramework.Modules.FrontPanel.display(data.name);
    },

    updateServiceData: function (isZapped) {
        isZapped = typeof isZapped == 'undefined' ? false : isZapped;
        if (!this.isCreated) {
            return false;
        }
        var serviceList = UIMiniFramework.Globals.service.actuallServiceList || UIMiniFramework.Globals.service.activeServiceList;
        var channelIndex = UIMiniFramework.Globals.service.channelIndex;
        var isUhdEvent = PluginInterface.ServiceZapper.fCheckOccasionalUhdEvent();
        if (isUhdEvent) {
            channelIndex = PluginInterface.ServiceZapper.fGetUhdChannelIndex();
        }
        var data = PluginInterface.ServiceZapper.fGetServiceData(serviceList, channelIndex);
        //console.log('UPDATE SERVICE DATA: LIST = ' + serviceList + ' | SERVCIE INDEX = ' + UIMiniFramework.Globals.service.channelIndex)
        //UIMiniFramework.Tools.printObject(data);
        this.setIndicator(this.indicators.lock.key, data.isLocked);
        this.setIndicator(this.indicators.paytv.key, data.scrambled);
        this.setIndicator(this.indicators.skip.key, data.isSkipped);
        this.setIndicator(this.indicators.hd.key, UIMiniFramework.Tools.isHd(data.type));
        this.setIndicator(this.indicators.uhd.key, UIMiniFramework.Tools.isUhd(data.type));
        this.updateChannelTitle(data.name);
        this.setFrequency(data.frequency);
        this.setNetworkName(data.networkName);
        if (isZapped) {
            UIMiniFramework.Globals.service.lcn = parseInt(data.pslIndex, 10);
            UIMiniFramework.Globals.service.serviceName = data.name;
        }
        if (data.isServiceActive == 1 || isZapped) {
            this.setActiveChannelIcon(true);
            this.updateServiceIndicators();
        }
        else {
            this.setActiveChannelIcon(false);
            this.resetServiceIndicators();
        }
    },

    updateServiceIndicators: function () {
        var components = PluginInterface.StreamComponents.fGetStreamComponentsInfo();
        if (components != null) {
            this.setIndicator(this.indicators.aud.key, components[0] == "1");
            this.setIndicator(this.indicators.sub.key, components[2] == "1");
            this.setIndicator(this.indicators.ttx.key, components[3] == "1");
            this.setIndicator(this.indicators.dolby.key, components[4] == "1");
            this.setIndicator(this.indicators.hbbtv.key, components[5] == "1");
        }
    },

    setRecording: function () {
        if (!UIMiniFramework.Config.MODULES.Pvr) {
            return;
        }
        // todo: handle service list -> var serviceList = UIMiniFramework.Globals.service.actuallServiceList || UIMiniFramework.Globals.service.activeServiceList;
        var formattedStringArgument = PluginInterface.Epg.fGetEpgFollowingString(UIMiniFramework.Globals.service.activeServiceList, UIMiniFramework.Globals.service.channelIndex); //TODO: use fGetEpgScheduledData function instead of this!
        formattedStringArgument = UIMiniFramework.Modules.Pvr.addPvrPaddings(formattedStringArgument);

        // process recording lack of storage calculation
        var durationString = formattedStringArgument.split('|')[7];
        var durationSeconds = UIMiniFramework.Tools.getSecondsFromTimeString(durationString);
        var serviceType = UIMiniFramework.ServiceListCache.serviceList[UIMiniFramework.Globals.service.activeServiceList][UIMiniFramework.Globals.service.channelIndex].type;
        if (!$('.infoBanner .section1.eventTitle').hasClass('scheduled')) {
            if (UIMiniFramework.Modules.Pvr.isRecordingLackOfStorage(durationSeconds, serviceType)) {
                return;
            }
        }

        // update schedule title
        var serviceName = UIMiniFramework.ServiceListCache.serviceList[UIMiniFramework.Globals.service.activeServiceList][UIMiniFramework.Globals.service.channelIndex].name;
        var dataArray = formattedStringArgument.split('|');
        var title = dataArray[0];
        dataArray[0] = serviceName + ' ' + title; // title updated
        formattedStringArgument = dataArray.join('|');

        var result = PluginInterface.Pvr.fCreateTimerRecord(formattedStringArgument, UIMiniFramework.Globals.service.channelIndex, UIMiniFramework.Globals.service.activeServiceList);
        ui.App.Callbacks.createTimerRecordResponse(result);
        switch (parseInt(result, 10)) {
            case PluginInterface.Pvr.eScheduleRecordingStatus.SUCCESS:
                $('.infoBanner .section1.eventTitle').addClass('scheduled');
                break;
            case PluginInterface.Pvr.eScheduleRecordingStatus.ERROR:
                break;
            case PluginInterface.Pvr.eScheduleRecordingStatus.REMOVED:
                $('.infoBanner .section1.eventTitle').removeClass('scheduled');
                break;
        }
    },

    setReminder: function () {
        var listIndex = PluginInterface.ServiceZapper.fGetActiveServiceList();
        var formattedStringArgument = PluginInterface.Epg.fGetEpgFollowingString(listIndex, UIMiniFramework.Globals.service.channelIndex);
        // update schedule title
        var serviceName = UIMiniFramework.ServiceListCache.serviceList[listIndex][UIMiniFramework.Globals.service.channelIndex].name;
        var dataArray = formattedStringArgument.split('|');
        var title = dataArray[0];
        dataArray[0] = serviceName + ' ' + title; // title updated
        formattedStringArgument = dataArray.join('|');

        var result = PluginInterface.Reminder.fSetReminderData(formattedStringArgument, UIMiniFramework.Globals.service.channelIndex, listIndex);
        ui.App.Callbacks.setReminderDataResponse(result);
        switch (parseInt(result, 10)) {
            case PluginInterface.Reminder.eScheduleReminderStatus.SUCCESS:
                $('.infoBanner .section1.eventTitle').addClass('remind');
                break;
            case PluginInterface.Reminder.eScheduleReminderStatus.REMOVED:
                $('.infoBanner .section1.eventTitle').removeClass('remind');
                break;
        }
    },

    red: function () {
        if (!UIMiniFramework.Globals.service.isZapped) {
            return true;
        }
        if (!UIMiniFramework.Globals.isSignalAvailable) {
            UIMiniFramework.Modules.Notifications.add(UIMiniFramework.Translations.noSignal[UIMiniFramework.Globals.language]);
            return true;
        }
        switch (this.mode) {
            case this.modes.SHORT:
            case this.modes.SERVICE:
                return true;
            case this.modes.EXTENDED:
                if (!PluginInterface.Setup.getPvrActivated()) {
                    return UIMiniFramework.Tools.recordingDisabledInformation();
                }
                switch (this.eventType) {
                    case PluginInterface.ServiceZapper.eventType.PRESENT:
                        if (UIMiniFramework.Config.MODULES.Pvr) {
                            UIMiniFramework.Modules.Pvr.oneTouchRecording.start();
                        }
                        break;
                    case PluginInterface.ServiceZapper.eventType.FOLLOWING:
                        if (!UIMiniFramework.Modules.UsbDevices.recorder.isMounted) {
                            UIMiniFramework.Modules.UsbDevices.usbNotReady();
                            return;
                        }
                        var isRecordingSet = $('.infoBanner .section1.eventTitle').hasClass('scheduled');
                        if (!isRecordingSet) {
                            this.setRecording();
                        }
                        else {
                            UIMiniFramework.Modules.Confirmations.add(
                                UIMiniFramework.Translations.popups.doYouWantToDiscardTimer[UIMiniFramework.Globals.language],
                                null,
                                UIMiniFramework.Modules.InfoBanner.setRecording.bind(UIMiniFramework.Modules.InfoBanner),
                                null,
                                false,
                                false,
                                false,
                                null,
                                null,
                                false
                            );
                        }
                        break;
                }
                return true;
        }
    },

    green: function () {
        if (this.eventType == PluginInterface.ServiceZapper.eventType.PRESENT || !UIMiniFramework.Globals.service.isZapped) {
            return true;
        }
        if (!UIMiniFramework.Globals.isSignalAvailable) {
            UIMiniFramework.Modules.Notifications.add(UIMiniFramework.Translations.noSignal[UIMiniFramework.Globals.language]);
            return true;
        }
        switch (this.mode) {
            case this.modes.SHORT:
            case this.modes.SERVICE:
                break;
            case this.modes.EXTENDED:
                var isReminderSet = $('.infoBanner .section1.eventTitle').hasClass('remind');
                if (!isReminderSet) {
                    this.setReminder();
                }
                else {
                    UIMiniFramework.Modules.Confirmations.add(
                        UIMiniFramework.Translations.popups.doYouWantToDiscardTimer[UIMiniFramework.Globals.language],
                        null,
                        UIMiniFramework.Modules.InfoBanner.setReminder.bind(UIMiniFramework.Modules.InfoBanner),
                        null,
                        false,
                        false,
                        false,
                        null,
                        null,
                        false
                    );
                }
                break;
        }
        return true;
    },

    ok: function () {
        if (UIMiniFramework.Globals.service.isZapOnDigitInProgress) {
            return true;
        }
        if (UIMiniFramework.Globals.service.lcn == this.shiftedLcn) {
            //do not zap just close info banner
            this.destroy();
            return true;
        }
        // destroy clears UIMiniFramework.Globals.service.channelIndex and UIMiniFramework.Globals.service.activeServiceList
        var index = UIMiniFramework.Globals.service.channelIndex;
        var activeList = UIMiniFramework.Globals.service.activeServiceList;
        UIMiniFramework.Globals.service.actuallServiceList = null;
        this.destroy();
        if (index != PluginInterface.ServiceZapper.fGetActiveService(activeList)) {
            UIMiniFramework.Modules.ZapperWrapper.setActiveService(activeList, index);
        }
        return true;
    },

    left: function(){
        if (!UIMiniFramework.Globals.service.isZapped) {
            return true;
        }
        if (this.mode == this.modes.SHORT) {
            this.postponeCloseTimeout();
        }
        this.shiftHorizontal(-1);
        return true;
    },

    right: function(){
        if (!UIMiniFramework.Globals.service.isZapped) {
            return true;
        }
        if (this.mode == this.modes.SHORT) {
            this.postponeCloseTimeout();
        }
        this.shiftHorizontal(1);
        return true;
    },

    up: function(){
        if (!UIMiniFramework.Globals.service.isZapped) {
            return true;
        }
        if (this.mode == this.modes.SHORT) {
            this.postponeCloseTimeout();
            this.shiftVertical(-1);
        }
        else if (this.mode == this.modes.EXTENDED) {
            this.scrollVertical(-1)
        }
        return true;
    },

    down: function(){
        if (!UIMiniFramework.Globals.service.isZapped) {
            return true;
        }
        if (this.mode == this.modes.SHORT) {
            this.postponeCloseTimeout();
            this.shiftVertical(1);
        }
        else if (this.mode == this.modes.EXTENDED) {
            this.scrollVertical(1)
        }
        return true;
    },

    number: function(keyCode){
        UIMiniFramework.Modules.ZapperWrapper.setServiceOnDigit(keyCode);
    },

    handleKeyPress: function (keyCode) {
        switch (keyCode) {
            case UIMiniFramework.Keys.OK:
                return this.ok();
            case UIMiniFramework.Keys.Left:
                return this.left();
            case UIMiniFramework.Keys.Right:
                return this.right();
            case UIMiniFramework.Keys.Up:
                return this.up();
            case UIMiniFramework.Keys.Down:
                return this.down();
            case UIMiniFramework.Keys.Back:
                this.toggleMode(-1);
                return true;
            case UIMiniFramework.Keys.Info:
                this.toggleMode(1);
                return true;
            case UIMiniFramework.Keys.Red:
                return true;
                return this.red();
            case UIMiniFramework.Keys.Green:
                return true;
                return this.green();
            case UIMiniFramework.Keys.ChannelUp:
                UIMiniFramework.Modules.ZapperWrapper.setNextService();
                return true;
            case UIMiniFramework.Keys.ChannelDown:
                UIMiniFramework.Modules.ZapperWrapper.setPreviousService();
                return true;
            case UIMiniFramework.Keys.Num0:
            case UIMiniFramework.Keys.Num1:
            case UIMiniFramework.Keys.Num2:
            case UIMiniFramework.Keys.Num3:
            case UIMiniFramework.Keys.Num4:
            case UIMiniFramework.Keys.Num5:
            case UIMiniFramework.Keys.Num6:
            case UIMiniFramework.Keys.Num7:
            case UIMiniFramework.Keys.Num8:
            case UIMiniFramework.Keys.Num9:
                this.number(keyCode - UIMiniFramework.Keys.Num0);
                return true;
            default:
                return false;
        }
    }
};